@@ -1,6 +1,6 @@
 import pandas as pd
 import numpy as np
-# 2018 Center for International Development at Harvard University 'ecomplexity' package imports
+# CID-Harvard ecomplexity package imports
 import warnings
 from ecomplexity.calc_proximity import calc_discrete_proximity
 from ecomplexity.calc_proximity import calc_continuous_proximity
@@ -8,258 +8,278 @@ from ecomplexity.ComplexityData import ComplexityData
 from ecomplexity.density import calc_density
 from ecomplexity.coicog import calc_coi_cog
 
+
 # IO-PS framework value chain mapping
-def iops(tradeData, GVC_Mapping = None, countryCode=711, tradeDigit=6):
+def iops(tradedata, valuechain=None, countrycode=710, tradedigit=6, statanorm=False):
+    """ IO-PS calculation function that writes the results to .xls and .csv
+        Args:
+            tradedata: pandas dataframe containing raw CEPII-BACI trade data.
+            valuechain: .csv of the value chain the IO-PS will map.
+                columns - 'tier', 'category', 'trade code'
+                default - None
+            countrycode: integer indicating which country the IO-PS will map.
+                default - 710
+            tradedigit: Integer of 6 or 4 to indicate the raw trade digit summation level.
+                default - 6
+            statanorm: Boolean indicator of literature based or CID-Harvard STATA normalization.
+                default - False
+        """
 
-    # Trade data formatting using 'digitSumm' function
-    eData = digitSumm(tradeData, tradeDigit)
+    # Trade data formatting using digitsumm function
+    edata = digitsumm(tradedata, tradedigit)
+    # Computation of product space metrics using psmetrics function
+    cdata = psmetrics(edata, statanorm)
 
-    # Computation of product space metrics using 'psMetrics' function
-    cData = psMetrics(eData)
-
-    # Default the IO-PS mapping to all products, at trade digit levels, if no value chain is input
-    if GVC_Mapping is None:
-        # Country subset of Product Space metrics for use during IO-PS calculations
-        # Store the subset of data associated with the input country
-        country_df = cData[cData['i'] == countryCode].copy(deep=True)
+    # Default the IO-PS mapping to all products, at trade digit levels, if no value chain is input.
+    if valuechain is None:
+        # Store the subset of data associated with the input country code.
+        country_df = cdata[cdata['i'] == countrycode].copy(deep=True)
         print("Pre-mappings complete")
 
-        # Binary RCA assignment for IO=PS calculations
-        # Country Mcp column
+        # Binary RCA assignment for IO-PS calculations.
+        # Country dataframe Mcp column.
         country_df['Mcp'] = 0
+        # Set Mcp column to a value of 1 for all products in the value chain for which the country has an RCA > 1.
         country_df.loc[country_df['rca'] >= 1, 'Mcp'] = 1
-        # All data Mcp
-        cData['Mcp'] = 0
-        cData.loc[cData['rca'] >= 1, 'Mcp'] = 1
+        # All data dataframe Mcp column.
+        cdata['Mcp'] = 0
+        cdata.loc[cdata['rca'] >= 1, 'Mcp'] = 1
         print("RCA assignment complete")
 
         print('No value chain input, calculating default at trade digit levels')
-        # Aggregate raw trade data to the user specified trade digit level
-        if tradeDigit == 4:
+        # Aggregate raw trade data to the user specified trade digit level.
+        if tradedigit == 4:
             print('No value chain input, calculating default for 4-digit input')
             # Write 4-digit aggregation
-            country_df = cData.loc[cData['i'] == countryCode].copy(deep=True)
-            fourCountry_df = country_df[['t', 'k', 'Mcp', 'rca', 'distance', 'pci']]
+            country_df = cdata.loc[cdata['i'] == countrycode].copy(deep=True)
+            fourcountry_df = country_df[['t', 'k', 'Mcp', 'rca', 'distance', 'pci']]
             # Store column headings
-            fourCountry_df.columns = ['year', 'code','Mcp', 'Average RCA', 'Average distance', 'Average product complexity']
-            # Write the results to excel and csv
-            fourCountry_df.to_csv('noGVC4Digit_Results.csv', header=None, index=False)
-            fourCountry_df.to_excel('noGVC4Digit_Results.xlsx', index=False)
+            fourcountry_df.columns = ['year', 'code', 'Mcp', 'Average RCA', 'Average distance',
+                                      'Average product complexity']
+            # Write the results to .xls and .csv
+            fourcountry_df.to_csv('noGVC4Digit_Results.csv', header=None, index=False)
+            fourcountry_df.to_excel('noGVC4Digit_Results.xlsx', index=False)
             print('No value chain 4-digit results calculated')
 
             print('No value chain input, calculating default for 2-digit input')
             # Create 2-digit level codes
-            digitEstimate = country_df.k / 100
+            digit_estimate = country_df.k / 100
             # Store codes as nearest lower integer
-            digitNew = np.floor(digitEstimate).astype(int)
+            digit_new = np.floor(digit_estimate).astype(int)
             # Add new column at 2-digit level
-            country_df['2k'] = digitNew
+            country_df['2k'] = digit_new
             # Store new digits and key metrics
-            twoCountry_df = country_df[['t', '2k', 'rca', 'distance', 'pci']]
+            twocountry_df = country_df[['t', '2k', 'rca', 'distance', 'pci']]
             # Sum export values to new 2-digit level and reset index
-            twoCountry_df = twoCountry_df.groupby(['t', '2k']).mean().reset_index()
+            twocountry_df = twocountry_df.groupby(['t', '2k']).mean().reset_index()
             # Store column headings
-            twoCountry_df.columns = ['year', 'code', 'Average RCA', 'Average distance', 'Average product complexity']
-            # Write the results to excel and csv
-            twoCountry_df.to_csv('noGVC2Digit_Results.csv', header=None, index=False)
-            twoCountry_df.to_excel('noGVC2Digit_Results.xlsx', index=False)
+            twocountry_df.columns = ['year', 'code', 'Average RCA', 'Average distance', 'Average product complexity']
+            # Write the results to .xls and .csv
+            twocountry_df.to_csv('noGVC2Digit_Results.csv', header=None, index=False)
+            twocountry_df.to_excel('noGVC2Digit_Results.xlsx', index=False)
             print('No value chain 2-digit results calculated')
         else:
             print('No value chain input, calculating default for 6-digit input')
             # Store 6-digit aggregation data
-            country_df = cData.loc[cData['i'] == countryCode].copy(deep=True)
-            sixCountry_df = country_df[['t', 'k', 'Mcp', 'rca', 'distance', 'pci']]
+            country_df = cdata.loc[cdata['i'] == countrycode].copy(deep=True)
+            sixcountry_df = country_df[['t', 'k', 'Mcp', 'rca', 'distance', 'pci']]
             # Store column headings
-            sixCountry_df.columns = ['year', 'code', 'Mcp', 'Average RCA', 'Average distance', 'Average product complexity']
-            # Write the results to excel and csv
-            sixCountry_df.to_csv('noGVC6Digit_Results.csv', header=None, index=False)
-            sixCountry_df.to_excel('noGVC6Digit_Results.xlsx', index=False)
+            sixcountry_df.columns = ['year', 'code', 'Mcp', 'Average RCA', 'Average distance',
+                                     'Average product complexity']
+            # Write the results to .xls and .csv
+            sixcountry_df.to_csv('noGVC6Digit_Results.csv', header=None, index=False)
+            sixcountry_df.to_excel('noGVC6Digit_Results.xlsx', index=False)
             print('No value chain 6-digit results calculated')
 
             print('No value chain input, calculating default for 4-digit input')
             # Create 4-digit codes
-            digitEstimate = country_df.k / 100
+            digit_estimate = country_df.k / 100
             # Store 4-digit estimates as nearest lower integer
-            digitNew = np.floor(digitEstimate).astype(int)
+            digit_new = np.floor(digit_estimate).astype(int)
             # Add a new column containing the 4-digit level codes
-            country_df['4k'] = digitNew
+            country_df['4k'] = digit_new
             # Store new digits and key metrics
-            fourCountry_df = country_df[['t', '4k', 'rca', 'distance', 'pci']]
+            fourcountry_df = country_df[['t', '4k', 'rca', 'distance', 'pci']]
             # Sum export values to new 4-digit level and reset index
-            fourCountry_df =fourCountry_df.groupby(['t', '4k']).mean().reset_index()
+            fourcountry_df = fourcountry_df.groupby(['t', '4k']).mean().reset_index()
             # Store column headings
-            fourCountry_df.columns = ['year', 'code', 'Average RCA', 'Average distance', 'Average product complexity']
-            # Write the results to excel and csv
-            fourCountry_df.to_csv('noGVC4Digit_Results.csv', header=None, index=False)
-            fourCountry_df.to_excel('noGVC4Digit_Results.xlsx', index=False)
+            fourcountry_df.columns = ['year', 'code', 'Average RCA', 'Average distance', 'Average product complexity']
+            # Write the results to .xls and .csv
+            fourcountry_df.to_csv('noGVC4Digit_Results.csv', header=None, index=False)
+            fourcountry_df.to_excel('noGVC4Digit_Results.xlsx', index=False)
             print('No value chain 4-digit results calculated')
 
             print('No value chain input, calculating default for 2-digit input')
             # Create 2-digit level codes
-            digitEstimate = country_df.k / 10000
+            digit_estimate = country_df.k / 10000
             # Store codes as nearest lower integer
-            digitNew = np.floor(digitEstimate).astype(int)
+            digit_new = np.floor(digit_estimate).astype(int)
             # Add new column at 2-digit level
-            country_df['2k'] = digitNew
+            country_df['2k'] = digit_new
             # Store new digits and key metrics
-            twoCountry_df = country_df[['t', '2k', 'rca', 'distance', 'pci']]
+            twocountry_df = country_df[['t', '2k', 'rca', 'distance', 'pci']]
             # Sum export values to new 2-digit level and reset index
-            twoCountry_df = twoCountry_df.groupby(['t', '2k']).mean().reset_index()
+            twocountry_df = twocountry_df.groupby(['t', '2k']).mean().reset_index()
             # Store column headings
-            twoCountry_df.columns = ['year', 'code', 'Average RCA', 'Average distance', 'Average product complexity']
-            # Write the results to excel and csv
-            twoCountry_df.to_csv('noGVC2Digit_Results.csv', header=None, index=False)
-            twoCountry_df.to_excel('noGVC2Digit_Results.xlsx', index=False)
+            twocountry_df.columns = ['year', 'code', 'Average RCA', 'Average distance', 'Average product complexity']
+            # Write the results to .xls and .csv
+            twocountry_df.to_csv('noGVC2Digit_Results.csv', header=None, index=False)
+            twocountry_df.to_excel('noGVC2Digit_Results.xlsx', index=False)
             print('No value chain 2-digit results calculated')
-
     else:
-        # Country and value chain subsets of Product Space metrics for use during IO-PS calculations
-        # Create column headings for the value chain dataframe to enable merging on column names
-        GVC_Mapping.columns = ['Tier', 'Category', 'k']
+        # Create column headings for the value chain dataframe to enable merging on column names.
+        valuechain.columns = ['Tier', 'Category', 'k']
         # Store the subset of data associated with the input country
-        country_df = cData[cData['i'] == countryCode].copy(deep=True)
+        country_df = cdata[cdata['i'] == countrycode].copy(deep=True)
         # Map the value chain to the country
-        GVC_df = pd.merge(GVC_Mapping, country_df, on='k', how='left')
+        valuechain_df = pd.merge(valuechain, country_df, on='k', how='left')
         print("Pre-mappings complete")
 
-        # Binary RCA assignment for value chain calculations
-        # Value Chain Mcp column created and initialized to 0
-        GVC_df['Mcp'] = 0
-        # Set 'Mcp' column to a value of 1 for all products in the value chain for which the country has an RCA > 1
-        GVC_df.loc[GVC_df['rca'] >= 1, 'Mcp'] = 1
+        # Binary RCA assignment for value chain calculations.
+        # Value Chain Mcp column created and initialized to 0.
+        valuechain_df['Mcp'] = 0
+        # Set Mcp column to a value of 1 for all products in the value chain for which the country has an RCA > 1.
+        valuechain_df.loc[valuechain_df['rca'] >= 1, 'Mcp'] = 1
         # Country Mcp column
         country_df['Mcp'] = 0
         country_df.loc[country_df['rca'] >= 1, 'Mcp'] = 1
         # All data Mcp
-        cData['Mcp'] = 0
-        cData.loc[cData['rca'] >= 1, 'Mcp'] = 1
+        cdata['Mcp'] = 0
+        cdata.loc[cdata['rca'] >= 1, 'Mcp'] = 1
         print("RCA assignment complete")
 
-        # GVC tier results for value chain input
+        # Value chain tier results for value chain input
         print('Starting GVC tier result calculation')
-        GVCTierResults = []
-        # Loop through each tier of the value chain and calculate the IO-PS metrics
-        for tierCount in range(len(GVC_Mapping.Tier.unique())):
-            GVCTierResults.append([])
-            # Store the subset of the value chain dataframe that corresponds to the current tier counter
-            tierTemp = GVC_df[GVC_df['Tier'] == tierCount + 1]
+        vc_tier_results = []
+        # Loop through each tier of the value chain and calculate the IO-PS metrics.
+        for tierCount in range(len(valuechain.Tier.unique())):
+            vc_tier_results.append([])
+            # Store the subset of the value chain dataframe that corresponds to the current tier counter.
+            tiertemp = valuechain_df[valuechain_df['Tier'] == tierCount + 1]
             # Tier number
-            GVCTierResults[tierCount].append(tierCount + 1)
+            vc_tier_results[tierCount].append(tierCount + 1)
             # Average RCA of the tier
-            GVCTierResults[tierCount].append(tierTemp['rca'].mean())
+            vc_tier_results[tierCount].append(tiertemp['rca'].mean())
             # Average distance of the tier
-            GVCTierResults[tierCount].append(tierTemp['distance'].mean())
+            vc_tier_results[tierCount].append(tiertemp['distance'].mean())
             # Average complexity of the tier
-            GVCTierResults[tierCount].append(tierTemp['pci'].mean())
+            vc_tier_results[tierCount].append(tiertemp['pci'].mean())
             # Average RCA of products yet to be obtained
-            GVCTierResults[tierCount].append(tierTemp[tierTemp['Mcp'] == 0]['rca'].mean())
+            vc_tier_results[tierCount].append(tiertemp[tiertemp['Mcp'] == 0]['rca'].mean())
             # Average distance of products yet to be obtained
-            GVCTierResults[tierCount].append(tierTemp[tierTemp['Mcp'] == 0]['distance'].mean())
+            vc_tier_results[tierCount].append(tiertemp[tiertemp['Mcp'] == 0]['distance'].mean())
             # Average complexity of products yet to be obtained
-            GVCTierResults[tierCount].append(tierTemp[tierTemp['Mcp'] == 0]['pci'].mean())
+            vc_tier_results[tierCount].append(tiertemp[tiertemp['Mcp'] == 0]['pci'].mean())
 
         # Store results as a dataframe
-        GVCTierResults = pd.DataFrame(GVCTierResults)
+        vc_tier_results = pd.DataFrame(vc_tier_results)
         # Label the column headings for readability
-        GVCTierResults.columns = ['Tier', 'Average RCA', 'Average distance', 'Average product complexity',
-                                 'Average RCA of products with RCA < 1', 'Average distance of products with RCA < 1',
-                                 'Average complexity of products with RCA < 1']
-        # Write the results to excel and csv
-        GVCTierResults.to_csv('Tier_Results.csv', header=None, index=False)
-        GVCTierResults.to_excel('Tier_Results.xlsx', index=False)
+        vc_tier_results.columns = ['Tier', 'Average RCA', 'Average distance', 'Average product complexity',
+                                   'Average RCA of products with RCA < 1', 'Average distance of products with RCA < 1',
+                                   'Average complexity of products with RCA < 1']
+        # Write the results to .xls and .csv
+        vc_tier_results.to_csv('Tier_Results.csv', header=None, index=False)
+        vc_tier_results.to_excel('Tier_Results.xlsx', index=False)
         print('GVC tier results calculated')
 
-        # GVC category results
+        # Value chain category results
         print('Starting GVC category result calculation')
-        GVCCatResults = []
-        # Loop through each category of the value chain and calculate the IO-PS metrics
-        for catCount in range(len(GVC_Mapping.Category.unique())):
-            GVCCatResults.append([])
-            # Store the subset of the value chain dataframe that corresponds to the current category counter
-            catTemp = GVC_df[GVC_df['Category'] == catCount + 1]
+        vc_category_results = []
+        # Loop through each category of the value chain and calculate the IO-PS metrics.
+        for catCount in range(len(valuechain.Category.unique())):
+            vc_category_results.append([])
+            # Store the subset of the value chain dataframe that corresponds to the current category counter.
+            cat_temp = valuechain_df[valuechain_df['Category'] == catCount + 1]
             # Append the tier of current category
-            GVCCatResults[catCount].append(catTemp['Tier'].iloc[0])
+            vc_category_results[catCount].append(cat_temp['Tier'].iloc[0])
             # Append the current category
-            GVCCatResults[catCount].append(catCount + 1)
+            vc_category_results[catCount].append(catCount + 1)
             # Append the aggregate RCA of the current category
-            GVCCatResults[catCount].append(catTemp['rca'].mean())
+            vc_category_results[catCount].append(cat_temp['rca'].mean())
             # Append the aggregate distance of the current category
-            GVCCatResults[catCount].append(catTemp['distance'].mean())
+            vc_category_results[catCount].append(cat_temp['distance'].mean())
             # Append the aggregate product complexity of the current category
-            GVCCatResults[catCount].append(catTemp['pci'].mean())
+            vc_category_results[catCount].append(cat_temp['pci'].mean())
             # Append the aggregate RCA of products in this category for which an RCA has not been obtained
-            GVCCatResults[catCount].append(catTemp[catTemp['Mcp'] == 0]['rca'].mean())
+            vc_category_results[catCount].append(cat_temp[cat_temp['Mcp'] == 0]['rca'].mean())
             # Append the aggregate distance of products in this category for which an RCA has not been obtained
-            GVCCatResults[catCount].append(catTemp[catTemp['Mcp'] == 0]['distance'].mean())
+            vc_category_results[catCount].append(cat_temp[cat_temp['Mcp'] == 0]['distance'].mean())
             # Append the aggregate complexity of products in this category for which an RCA has not been obtained
-            GVCCatResults[catCount].append(catTemp[catTemp['Mcp'] == 0]['pci'].mean())
+            vc_category_results[catCount].append(cat_temp[cat_temp['Mcp'] == 0]['pci'].mean())
 
-        # Store the results as a dataframe which places each set in the loop in a new row
-        GVCCatResults = pd.DataFrame(GVCCatResults)
+        # Store the results as a dataframe which places each set in the loop in a new row.
+        vc_category_results = pd.DataFrame(vc_category_results)
         # Label the column headings for readability
-        GVCCatResults.columns = ['Tier', 'Category', 'Average RCA', 'Average distance', 'Average product complexity',
-                                 'Average RCA of products with RCA < 1', 'Average distance of products with RCA < 1',
-                                 'Average complexity of products with RCA < 1']
-        # Write the results to excel and csv
-        GVCCatResults.to_csv('Product_Category_Results.csv', header=None, index=False)
-        GVCCatResults.to_excel('Product_Category_Results.xlsx', index=False)
+        vc_category_results.columns = ['Tier', 'Category', 'Average RCA', 'Average distance',
+                                       'Average product complexity',
+                                       'Average RCA of products with RCA < 1',
+                                       'Average distance of products with RCA < 1',
+                                       'Average complexity of products with RCA < 1']
+        # Write the results to .xls and .csv
+        vc_category_results.to_csv('Product_Category_Results.csv', header=None, index=False)
+        vc_category_results.to_excel('Product_Category_Results.xlsx', index=False)
         print('GVC category results calculated')
 
-        # GVC product results
+        # Value chain product results
         print('Starting GVC product results calculation')
-        # Subset the columns from the value chain for the output
-        GVCProdResults = GVC_df[['Tier','Category','k','rca','distance','pci']]
+        # Subset the columns from the value chain for the product level output.
+        vc_product_results = valuechain_df[['Tier', 'Category', 'k', 'rca', 'distance', 'pci']]
         # Rename the columns for readability
-        GVCProdResults.columns  = ['Tier', 'Category', 'Code', 'RCA', 'Distance', 'Complexity']
-        #GVCProdResults = pd.DataFrame(GVCProdResults)
-        # Write the results to excel and csv
-        GVCProdResults.to_csv('Product_Results.csv', header=None, index=False)
-        GVCProdResults.to_excel('Product_Results.xlsx', index=False)
+        vc_product_results.columns = ['Tier', 'Category', 'Code', 'RCA', 'Distance', 'Complexity']
+        # vc_product_results = pd.DataFrame(vc_product_results)
+        # Write the results to .xls and .csv
+        vc_product_results.to_csv('Product_Results.csv', header=None, index=False)
+        vc_product_results.to_excel('Product_Results.xlsx', index=False)
         print('GVC product results calculated')
     print("IOPS execution complete")
     return
 
-# Trade data pre-processing to retain export data only (at 4-digit or 6-digit level)
-def digitSumm(tradeData, tradeDigit):
+
+def digitsumm(tradedata, tradedigit):
+    """Trade data pre-processing, returns pandas dataframe of export data at 4-digit or 6-digit level"""
+
     print("Export data trade code summation started")
     # Trade data transformation to retain exports at the 4-digit level
-    if tradeDigit == 4:
+    if tradedigit == 4:
         # Remove the import value data from the raw trade data
-        eData = tradeData.drop(['j', 'q'], axis=1)
+        edata = tradedata.drop(['j', 'q'], axis=1)
         # Aggregate export value at the 6-digit level
-        eData = eData.groupby(['t', 'i', 'k']).sum().reset_index()
+        edata = edata.groupby(['t', 'i', 'k']).sum().reset_index()
         # Create the 4-digit codes
-        digitEstimate = eData.k / 100
+        digit_estimate = edata.k / 100
         # Store codes as nearest lower integer
-        digitNew = np.floor(digitEstimate).astype(int)
+        digit_new = np.floor(digit_estimate).astype(int)
         # Add a new column to the export data with the 4-digit level code
-        eData['k'] = digitNew
+        edata['k'] = digit_new
         # Sum export values to 4-digit level and reset index
-        eData = eData.groupby(['t', 'i', 'k']).sum().reset_index()
+        edata = edata.groupby(['t', 'i', 'k']).sum().reset_index()
         print("Export data 4-digit summation complete")
     else:
         # Trade data transformation to retain exports at the 6-digit level
         # Remove import data from the raw trade data
-        eData = tradeData.drop(['j', 'q'], axis=1)
+        edata = tradedata.drop(['j', 'q'], axis=1)
         # Sum export value to 6-digit code level and reset the index
-        eData = eData.groupby(['t', 'i', 'k']).sum().reset_index()
+        edata = edata.groupby(['t', 'i', 'k']).sum().reset_index()
         print("Export data 6-digit summation complete")
-    return eData
+    return edata
+
+
+def psmetrics(edata, statanorm):
+    """Product Space metric calculations on the aggregated export data, returns pandas dataframe"""
 
-# Product space metric calculations on the aggregated export data
-def psMetrics(eData):
     print("Product Space metric function started")
-    # CEPII BACI column values are changed to 'ecomplexity' package equivalents
-    tradeCols = {'time': 't', 'loc': 'i', 'prod': 'k', 'val': 'v'}
-    # Complexity and other metrics ar calculated using the 'ecomplexity' package
-    cData = ecomplexity(eData, tradeCols)
-    # The distance metric is added as a new column
-    cData['distance'] = 1 - cData['density']
+    # CEPII-BACI column values are changed to ecomplexity package equivalents.
+    tradecols = {'time': 't', 'loc': 'i', 'prod': 'k', 'val': 'v'}
+    # Complexity and other metrics ar calculated using the ecomplexity package.
+    cdata = ecomplexity(edata, tradecols, statanorm)
+    # The distance metric is added as a new column.
+    cdata['distance'] = 1 - cdata['density']
     print("Product Space metric function complete")
-    return cData
+    return cdata
 
-# The following functions are from the CID Harvard University 'ecomplexity' package (2018) under the MIT license
-# 'ecomplexity' function inputs have been altered to facilitate use within this package:
+
+# The following functions are from the CID-Harvard University ecomplexity package (2018) used under the MIT license
+# ecomplexity function inputs have been altered to facilitate use within this package:
 # https://github.com/cid-harvard/py-ecomplexity/blob/fed5d9b377b133a8431a05c347c4408086d789b2/ecomplexity/ecomplexity.py#L113
 def reshape_output_to_data(cdata, t):
     """Reshape output ndarrays to df"""
@@ -298,6 +318,7 @@ def reshape_output_to_data(cdata, t):
     cdata.output_list.append(cdata.output_t)
     return cdata
 
+
 def conform_to_original_data(cdata, data):
     """Reset column names and add dropped columns back"""
     cdata.output = cdata.output.rename(columns=cdata.cols_input)
@@ -306,6 +327,7 @@ def conform_to_original_data(cdata, data):
     )
     return cdata
 
+
 def calc_eci_pci(cdata):
     # Check if diversity or ubiquity is 0 or nan, can cause problems
     if ((cdata.diversity_t == 0).sum() > 0) | ((cdata.ubiquity_t == 0).sum() > 0):
@@ -359,8 +381,8 @@ def calc_eci_pci(cdata):
 
     return (eci_t, pci_t)
 
-def ecomplexity(data, cols_input):
 
+def ecomplexity(data, cols_input, statanorm=False):
     """Complexity calculations through the ComplexityData class
     Args:
         data: pandas dataframe containing production / trade data.
@@ -386,6 +408,7 @@ def ecomplexity(data, cols_input):
             to generate asymmetric proximity matrix (True) or symmetric (False).
             *default* False.
         verbose: Print year being processed
+        statanorm: Set method of PCI normalization
     Returns:
         Pandas dataframe containing the data with the following additional columns:
             - diversity: k_c,0
@@ -400,7 +423,7 @@ def ecomplexity(data, cols_input):
             - cog: Complexity Outlook Gain
     """
 
-# Set 'ecomplexity' function variables to their default and assign the two remaining arguments as normal
+    # Set ecomplexity function variables to their default and assign the two remaining arguments as normal.
     presence_test = "rca"
     val_errors_flag = "coerce"
     rca_mcp_threshold = 1
@@ -453,10 +476,17 @@ def ecomplexity(data, cols_input):
         # Calculate COI and COG
         cdata.coi_t, cdata.cog_t = calc_coi_cog(cdata, prox_mat)
 
-        # Normalize variables as per STATA package
-        # PCI normalization has been altered from the original:
+        # Output normalization has been altered from the original CID-Harvard code:
         # https://github.com/cid-harvard/py-ecomplexity/blob/fed5d9b377b133a8431a05c347c4408086d789b2/ecomplexity/ecomplexity.py#L209
-        cdata.pci_t = (cdata.pci_t - cdata.pci_t.mean()) / cdata.pci_t.std()
+        if statanorm == True:
+            # Normalize pci as per STATA package
+            print('Normalizing pci as per STATA package')
+            cdata.pci_t = (cdata.pci_t - cdata.eci_t.mean()) / cdata.eci_t.std()
+        else:
+            # Normalize pci as per literature
+            cdata.pci_t = (cdata.pci_t - cdata.pci_t.mean()) / cdata.pci_t.std()
+            print('Normalizing pci as per literature')
+        # Normalize eci and cog as per STATA package
         cdata.cog_t = cdata.cog_t / cdata.eci_t.std()
         cdata.eci_t = (cdata.eci_t - cdata.eci_t.mean()) / cdata.eci_t.std()
 
@@ -468,4 +498,4 @@ def ecomplexity(data, cols_input):
     cdata.output = pd.concat(cdata.output_list)
     cdata = conform_to_original_data(cdata, data)
 
-    return cdata.output
\ No newline at end of file
+    return cdata.output
